/**
 * Copyright (C) 2003-2005 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package sync4j.framework.notification;

import java.io.*;


/**
 * @author Stefano Nichele @ Funambol
 *
 * @version $Id: BitOutputStream.java,v 1.1 2005/05/16 17:32:55 nichele Exp $
 */
public class BitOutputStream {

    // ------------------------------------------------------------ Private data
    private OutputStream out;
    private int buffer;
    private int bitCount = 7;

    // ------------------------------------------------------------- Constructor
    public BitOutputStream(OutputStream out) {
        this.out = out;
    }

    // ----------------------------------------------------------- Public method
    synchronized public void writeBit(int bit) throws IOException {
        if (out == null)
            throw new IOException("Already closed");

        if (bit != 0 && bit != 1) {
            throw new IOException(bit + " is not a bit");
        }


        buffer |= bit << bitCount;

        bitCount--;

        if (bitCount == -1) {
            flush();
        }


    }

    private void flush() throws IOException {
        if (bitCount < 7) {
            out.write( (byte)buffer);
            bitCount = 7;
            buffer = 0;
        }
    }

    public void close() throws IOException {
        flush();
        out.close();
        out = null;
    }
}