/**
 * Copyright (C) 2003-2005 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package sync4j.framework.notification;

import sync4j.framework.core.dm.ddf.DMAcc;
import sync4j.framework.core.dm.ddf.SyncMLDM;
import sync4j.framework.core.bootstrap.BootStrap;


/**
 * Represent a engine for bootstrap and notification process
 * @author Stefano Nichele @ Funambol
 *
 * @version $Id: NotificationEngine.java,v 1.1 2005/05/16 17:32:55 nichele Exp $
 */
public interface NotificationEngine {

    // --------------------------------------------------------------- Constants
    public static final String CONTENT_TYPE_BOOTSTRAP = "application/vnd.syncml.dm+wbxml";


    // ---------------------------------------------------------- Public Methods

    /**
     * Sends a notification message.
     * @param messageType the type of the message. See {@link NotificationConstants} for details.
     * @param transportType the transport type used to send the message. See {@link NotificationConstants} for details.
     * @param sessionId the session id
     * @param phoneNumber the phone number of the target device
     * @param info application specific info
     * @param serverId the server identifier (necessary to calculate the digest of the message)
     * @param serverPassword the server password (necessary to calculate the digest of the message)
     * @param serverNonce the server nonce (necessary to calculate the digest of the message)
     * @throws NotificationException if a error occurs
     */
    public void sendNotificationMessage(int messageType,
                                        int transportType,
                                        int sessionId,
                                        String phoneNumber,
                                        String info,
                                        String serverId,
                                        String serverPassword,
                                        byte[] serverNonce) throws NotificationException;


    /**
     * Sends more notification messages.
     * @param messageType the type of the message. See {@link NotificationConstants} for details.
     * @param transportType the transport type used to send the message. See {@link NotificationConstants} for details.
     * @param sessionIds the session identifiers
     * @param phoneNumbers the phone numbers list of the target devices
     * @param info application specific info
     * @param serverId the server identifier (necessary to calculate the digest of the message)
     * @param serverPassword the server passwords list (necessary to calculate the digest of the message)
     * @param serverNonce the server nonces list (necessary to calculate the digest of the message)
     * @throws NotificationException if a error occurs
     */
    public void sendNotificationMessages(int      messageType,
                                         int      transportType,
                                         int[]    sessionIds,
                                         String[] phoneNumbers,
                                         String   info,
                                         String   serverId,
                                         String[] serverPasswords,
                                         byte[][] serverNonces) throws NotificationException;


    /**
     * Sends a bootstrap message.
     * @param messageType  the type of the message. See {@link NotificationConstants} for details.
     * @param transportType the transport type used to send the message. See {@link NotificationConstants} for details.
     * @param serverUri the server uri
     * @param deviceUri the device uri
     * @param phoneNumber the phone number of the target device
     * @param syncMLDM the message to send
     * @param info application specific info
     * @throws NotificationException if a error occurs
     */
    public void sendBootstrapMessage(int messageType,
                                     int transportType,
                                     String serverUri,
                                     String deviceUri,
                                     String phoneNumber,
                                     SyncMLDM syncMLDM,
                                     String info) throws  NotificationException;


    /**
     * Sends bootstrap messages.
     * @param messageType  the type of the message. See {@link NotificationConstants} for details.
     * @param transportType the transport type used to send the message. See {@link NotificationConstants} for details.
     * @param bootstrap the bootstrap list
     * @param serverUri the server uri list
     * @param deviceUri the device uri list
     * @param phoneNumber the phone number list
     * @param syncMLDM the message list to send
     * @param info application specific info
     * @param
     * @throws NotificationException
     */
    public void sendBootstrapMessages(int messageType,
                                      int transportType,
                                      BootStrap[] bootstrap,
                                      String serverUri,
                                      SyncMLDM[] syncMLDM,
                                      String info) throws NotificationException;


    /**
     * Prepare bootstrap message
     * @param messageType the type of the message. See {@link NotificationConstants} for details.
     * @param bootstrap the bootstrap list
     * @param serverUri the server uri list
     * @param syncMLDM the message list to send
     * @param info application specific info
     */
    public BootStrap[] prepareBootstrap(int messageType,
                                        BootStrap[] bootstrap,
                                        String serverUri,
                                        SyncMLDM[] syncMLDM,
                                        String info) throws NotificationException;


    /**
     * Sends a bootstrap message.
     * @param messageType  the type of the message. See {@link NotificationConstants} for details.
     * @param transportType the transport type used to send the message. See {@link NotificationConstants} for details.
     * @param phoneNumbers the phone numbers
     * @param authMethods the authentication methods
     * @param messages the messages
     * @param info application specific info
     * @throws NotificationException if a error occurs
     */
    public void sendBootstrapMessages(int      messageType,
                                      int      transportType,
                                      String[] phoneNumbers,
                                      String[] macs,
                                      int[]    authMethods,
                                      byte[][] messages,
                                      String   info) throws  NotificationException;


}