/**
 * Copyright (C) 2003-2005 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package sync4j.server.notification;

import java.util.logging.Logger;
import java.util.logging.Level;

import sync4j.framework.logging.Sync4jLogger;
import sync4j.framework.notification.Sender;
import sync4j.framework.notification.NotificationException;


/**
 * This is a simple implementation of the Sender interface that simply logs its
 * activity.
 *
 * @author Stefano Fornari @ Funambol
 *
 * @version $Id: SimpleSender.java,v 1.1 2005/05/16 17:32:56 nichele Exp $
 */
public class SimpleSender implements Sender {


    // ---------------------------------------------------------- Public Methods

    /**
     * Sends a message
     * @param messageType the type of the message. See {@link NotificationConstants}
     * @param phoneNumber the phone number of the target device
     * @param message the messagge to send
     * @param info application specific info
     * @throws NotificationException
     */
    public void sendMessage(int    messageType,
                            String phoneNumber,
                            byte[] message    ,
                            String info       )
    throws NotificationException {
        Logger log = Sync4jLogger.getLogger();

        if (log.isLoggable(Level.INFO)) {
            log.info( "Send message(\n\tmessageType: "
                    + messageType
                    + "\n\tphoneNumber: "
                    + phoneNumber
                    + "\n\tmessage length: "
                    + ((message != null) ? String.valueOf(message.length) : "unknown")
                    + "\n\tinfo: "
                    + info
            );
        }
    }

    /**
     * Sends messages
     * @param messageType the type of the message. See {@link NotificationConstants}
     * @param phoneNumbers the phone numbers list of the target device
     * @param messages the messages to send
     * @param info application specific info
     * @throws NotificationException
     */
    public void sendMessages(int      messageType,
                             String[] phoneNumbers,
                             byte[][] message,
                             String   info) throws NotificationException {
        Logger log = Sync4jLogger.getLogger();

        if (log.isLoggable(Level.INFO)) {
            log.info( "Sends messages(\n\tmessageType: "
                      + messageType
                      + "\n\tnum. devices: "
                      + phoneNumbers.length
                      + "\n\tinfo: "
                      + info
                );
            log.info("sendMessages with empty implementation");
        }
    }

    /**
     * Sends more messages
     * @param messageType the type of the message. See {@link NotificationConstants}
     * @param contentType the contentType
     * @param macs the macs list
     * @param authMethods the authentication methods
     * @param phoneNumbers the phone number list
     * @param messages the messages to send
     * @param info application specific info
     * @throws NotificationException
     */
    public void sendMessages(int messageType,
                             String contentType,
                             String[] digest,
                             int[]    authMethods,
                             String[] phoneNumbers,
                             byte[][] messages,
                             String info) throws NotificationException {

    }



}